@@ -1,5 +1,5 @@
 import pandas as pd
-from aistac.handlers.abstract_handlers import AbstractSourceHandler, ConnectorContract
+from aistac.handlers.abstract_handlers import AbstractSourceHandler, ConnectorContract, HandlerFactory
 
 __author__ = 'Darryl Oatridge, Neil Pasricha'
 
@@ -7,10 +7,9 @@ __author__ = 'Darryl Oatridge, Neil Pasricha'
 class HiveSourceHandler(AbstractSourceHandler):
     """ A Hive source handler"""
 
-    from pyhive import hive
-
     def __init__(self, connector_contract: ConnectorContract):
         """ initialise the Handler passing the source_contract dictionary """
+        self.pyhive = HandlerFactory.get_module('pyhive.hive')
         super().__init__(connector_contract)
         self._modified = 0
 
@@ -36,9 +35,10 @@ class HiveSourceHandler(AbstractSourceHandler):
         canonical = self.connector_contract.get_key_value('canonical', 'dict')
         query = self.connector_contract.query
         host_name, port = host.rsplit(sep=':')
-        conn = self.hive.Connection(host=host_name, port=port, username=user, password=password, database=database,
-                               configuration=configuration, auth=auth, kerberos_service_name=kerberos_service_name,
-                               thrift_transport=thrift_transport, **kwargs)
+        conn = self.pyhive.hive.Connection(host=host_name, port=port, username=user, password=password,
+                                           database=database, configuration=configuration, auth=auth,
+                                           kerberos_service_name=kerberos_service_name,
+                                           thrift_transport=thrift_transport, **kwargs)
         # return a pandas DataFrame
         if canonical.lower().endswith('pandas'):
             return pd.read_sql(query, conn)
@@ -57,6 +57,9 @@ class HiveSourceHandler(AbstractSourceHandler):
         cursor.close()
         return rtn_dict
 
-
     def get_modified(self) -> [int, float, str]:
         return self._modified
+
+    def exists(self) -> bool:
+        raise NotImplementedError("This fuction is not yet implemented for Hive")
+
